"""update imaging workflows for transfer plugin

Revision ID: 119347106acd
Revises: 88543565c9e5
Create Date: 2021-11-04 16:20:46.735603

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "119347106acd"
down_revision = "88543565c9e5"
branch_labels = None
depends_on = None


cms_envoy = """executable = std_cms_imaging_envoy.sh
arguments = metadata.json PPR.xml

output = imaging_envoy.out
error = imaging_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/.matplotlib, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/framework.sh, nraorsync://$(SBIN_PATH)/casa_envoy, nraorsync://$(SBIN_PATH)/vela{{#remote}}, nraorsync://$(SPOOL_DIR){{profile}}.properties{{/remote}}, nraorsync://$(SPOOL_DIR)/PPR.xml, nraorsync://$(SPOOL_DIR)/metadata.json, nraorsync://$(CMS_PATH)/{{sdmId}}.ms{{files_to_transfer}}
when_to_transfer_files = ON_EXIT
transfer_output_files = .job.ad
+nrao_output_files = "working rawdata products"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True
{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue

"""

cms_convey = """executable = std_cms_imaging_convey.sh
arguments = metadata.json

output = imaging_convey.out
error = imaging_convey.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/conveyor, nraorsync://$(SPOOL_DIR)/metadata.json, nraorsync://$(SPOOL_DIR)/working, nraorsync://$(SPOOL_DIR)/rawdata, nraorsync://$(SPOOL_DIR)/products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""

old_cms_envoy = """executable = std_cms_imaging_envoy.sh
arguments = metadata.json PPR.xml

output = imaging_envoy.out
error = imaging_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela{{#remote}}, {{profile}}.properties{{/remote}}, ./PPR.xml, ./metadata.json, $(CMS_PATH)/{{sdmId}}.ms{{files_to_transfer}}
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue

"""

old_cms_convey = """executable = std_cms_imaging_convey.sh
arguments = metadata.json

output = imaging_convey.out
error = imaging_convey.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
CMS_PATH = {{cms_path}}
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, ./metadata.json, ./working, ./rawdata, ./products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

restore_fetch = """executable = std_restore_imaging_fetch.sh
arguments = {{product_locator}} {{cal_locator}}

output = restore_img_fetch.out
error = restore_img_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/framework.sh, nraorsync://$(SBIN_PATH)/productfetcher
when_to_transfer_files = ON_EXIT
transfer_output_files = .job.ad 
+nrao_output_files = "working rawdata products"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

old_restore_fetch = """executable = std_restore_imaging_fetch.sh
arguments = {{product_locator}} {{cal_locator}}

output = restore_img_fetch.out
error = restore_img_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

restore_envoy = """executable = std_restore_imaging_envoy.sh
arguments = metadata.json PPR.xml

output = restore_img_envoy.out
error = restore_img_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/.matplotlib, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/framework.sh, nraorsync://$(SBIN_PATH)/casa_envoy, nraorsync://$(SBIN_PATH)/vela, nraorsync://$(SPOOL_DIR)/working, nraorsync://$(SPOOL_DIR)/rawdata, nraorsync://$(SPOOL_DIR)/products{{#remote}}, nraorsync://$(SPOOL_DIR)/{{profile}}.properties{{/remote}}, nraorsync://$(SPOOL_DIR)/PPR.xml, nraorsync://$(SPOOL_DIR)/metadata.json{{files_to_transfer}}
when_to_transfer_files = ON_EXIT
transfer_output_files = .job.ad
+nrao_output_files = "working rawdata products"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

old_restore_envoy = """executable = std_restore_imaging_envoy.sh
arguments = metadata.json PPR.xml

output = restore_img_envoy.out
error = restore_img_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, ./working, ./rawdata, ./products{{#remote}}, {{profile}}.properties{{/remote}}, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue

"""

restore_deliver = """executable = std_restore_imaging_deliver.sh
arguments = {{request_id}} {{spool_dir}}

output = restore_img_deliver.out
error = restore_img_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/deliver

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""

old_restore_deliver = """executable = std_restore_imaging_deliver.sh
arguments = {{request_id}} {{spool_dir}}

output = restore_img_deliver.out
error = restore_img_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue


"""


def upgrade():
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{cms_envoy}' WHERE filename='std_cms_imaging_envoy.condor'
            """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{cms_convey}' WHERE filename='std_cms_imaging_convey.condor'
            """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_fetch}' WHERE filename='std_restore_imaging_fetch.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_envoy}' WHERE filename='std_restore_imaging_envoy.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_deliver}' WHERE filename='std_restore_imaging_deliver.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_cms_envoy}' WHERE filename='std_cms_imaging_envoy.condor'
            """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_cms_convey}' WHERE filename='std_cms_imaging_convey.condor'
            """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_fetch}' WHERE filename='std_restore_imaging_fetch.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_envoy}' WHERE filename='std_restore_imaging_envoy.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_deliver}' WHERE filename='std_restore_imaging_deliver.condor'
        """
    )
